@@ -1,34 +1,37 @@
 ﻿/****************************************************************************
 **
 ** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtSerialBus module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL3$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
 ** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -127,6 +130,18 @@ static int deviceChannel(const QString &canDevice)
     return content.toInt(nullptr, 0);
 }
 
+QCanBusDeviceInfo SocketCanBackend::socketCanDeviceInfo(const QString &deviceName)
+{
+    const QString serial; // exists for code readability purposes only
+    const QString alias;  // exists for code readability purposes only
+    const QString description = deviceDescription(deviceName);
+    const int channel = deviceChannel(deviceName);
+    return createDeviceInfo(QStringLiteral("socketcan"), deviceName,
+                            serial, description,
+                            alias, channel, isVirtual(deviceName),
+                            isFlexibleDataRateCapable(deviceName));
+}
+
 QList<QCanBusDeviceInfo> SocketCanBackend::interfaces()
 {
     QList<QCanBusDeviceInfo> result;
@@ -143,12 +158,7 @@ QList<QCanBusDeviceInfo> SocketCanBackend::interfaces()
         if (!(flags(deviceName) & DeviceIsActive))
             continue;
 
-        const QString serial;
-        const QString description = deviceDescription(deviceName);
-        const int channel = deviceChannel(deviceName);
-        result.append(std::move(createDeviceInfo(deviceName, serial, description,
-                                                 channel, isVirtual(deviceName),
-                                                 isFlexibleDataRateCapable(deviceName))));
+        result.append(socketCanDeviceInfo(deviceName));
     }
 
     std::sort(result.begin(), result.end(),
@@ -159,6 +169,11 @@ QList<QCanBusDeviceInfo> SocketCanBackend::interfaces()
     return result;
 }
 
+QCanBusDeviceInfo SocketCanBackend::deviceInfo() const
+{
+    return socketCanDeviceInfo(canSocketName);
+}
+
 SocketCanBackend::SocketCanBackend(const QString &name) :
     canSocketName(name)
 {
@@ -171,16 +186,6 @@ SocketCanBackend::SocketCanBackend(const QString &name) :
     }
 
     resetConfigurations();
-
-    std::function<void()> f = std::bind(&SocketCanBackend::resetController, this);
-    setResetControllerFunction(f);
-
-    if (hasBusStatus()) {
-        // Only register busStatus when libsocketcan is available
-        // QCanBusDevice::hasBusStatus() will return false otherwise
-        std::function<CanBusStatus()> g = std::bind(&SocketCanBackend::busStatus, this);
-        setCanBusStatusGetter(g);
-    }
 }
 
 SocketCanBackend::~SocketCanBackend()
@@ -224,7 +229,7 @@ void SocketCanBackend::close()
     setState(QCanBusDevice::UnconnectedState);
 }
 
-bool SocketCanBackend::applyConfigurationParameter(int key, const QVariant &value)
+bool SocketCanBackend::applyConfigurationParameter(ConfigurationKey key, const QVariant &value)
 {
     bool success = false;
 
@@ -284,7 +289,7 @@ bool SocketCanBackend::applyConfigurationParameter(int key, const QVariant &valu
             break;
         }
 
-        QVector<can_filter> filters;
+        QList<can_filter> filters;
         filters.resize(filterList.size());
         for (int i = 0; i < filterList.size(); i++) {
             const QCanBusDevice::Filter f = filterList.at(i);
@@ -353,7 +358,7 @@ bool SocketCanBackend::applyConfigurationParameter(int key, const QVariant &valu
         break;
     }
     default:
-        setError(tr("SocketCanBackend: No such configuration as %1 in SocketCanBackend").arg(key),
+        setError(tr("Unsupported configuration key: %1").arg(key),
                  QCanBusDevice::CanBusError::ConfigurationError);
         break;
     }
@@ -401,7 +406,7 @@ bool SocketCanBackend::connectSocket()
 
     //apply all stored configurations
     const auto keys = configurationKeys();
-    for (int key : keys) {
+    for (ConfigurationKey key : keys) {
         const QVariant param = configurationParameter(key);
         bool success = applyConfigurationParameter(key, param);
         if (Q_UNLIKELY(!success)) {
@@ -413,7 +418,7 @@ bool SocketCanBackend::connectSocket()
     return true;
 }
 
-void SocketCanBackend::setConfigurationParameter(int key, const QVariant &value)
+void SocketCanBackend::setConfigurationParameter(ConfigurationKey key, const QVariant &value)
 {
     if (key == QCanBusDevice::RawFilterKey) {
         //verify valid/supported filters
@@ -457,7 +462,7 @@ void SocketCanBackend::setConfigurationParameter(int key, const QVariant &value)
 
     QCanBusDevice::setConfigurationParameter(key, value);
 
-    // we need to check CAN FD option a lot -> cache it and avoid QVector lookup
+    // we need to check CAN FD option a lot -> cache it and avoid QList lookup
     if (key == QCanBusDevice::CanFdKey)
         canFdOptionEnabled = value.toBool();
 }
@@ -530,7 +535,7 @@ QString SocketCanBackend::interpretErrorFrame(const QCanBusFrame &errorFrame)
     QString errorMsg;
 
     if (errorFrame.error() & QCanBusFrame::TransmissionTimeoutError)
-        errorMsg += QStringLiteral("TX timout\n");
+        errorMsg += QStringLiteral("TX timeout\n");
 
     if (errorFrame.error() & QCanBusFrame::MissingAcknowledgmentError)
         errorMsg += QStringLiteral("Received no ACK on transmission\n");
@@ -685,7 +690,7 @@ QString SocketCanBackend::interpretErrorFrame(const QCanBusFrame &errorFrame)
 
 void SocketCanBackend::readSocket()
 {
-    QVector<QCanBusFrame> newFrames;
+    QList<QCanBusFrame> newFrames;
 
     for (;;) {
         m_frame = {};
@@ -758,7 +763,7 @@ bool SocketCanBackend::hasBusStatus() const
     return libSocketCan->hasBusStatus();
 }
 
-QCanBusDevice::CanBusStatus SocketCanBackend::busStatus() const
+QCanBusDevice::CanBusStatus SocketCanBackend::busStatus()
 {
     return libSocketCan->busStatus(canSocketName);
 }
